@@ -1,29 +1,20 @@
+import doctest
 import re
 import unittest
-import grokcore.formlib
-import os.path
-
 from pkg_resources import resource_listdir
-from zope.testing import doctest, renormalizing
-from zope.app.testing.functional import (getRootFolder, FunctionalTestSetup,
-                                         ZCMLLayer)
 
-ftesting_zcml = os.path.join(os.path.dirname(grokcore.formlib.__file__),
-                             'ftesting.zcml')
-FunctionalLayer = ZCMLLayer(ftesting_zcml, __name__, 'FunctionalLayer',
-                            allow_teardown=True)
+from zope.testing import renormalizing
+from zope.app.wsgi.testlayer import BrowserLayer
+import grokcore.formlib
 
-def setUp(test):
-    FunctionalTestSetup().setUp()
-
-def tearDown(test):
-    FunctionalTestSetup().tearDown()
+FunctionalLayer = BrowserLayer(grokcore.formlib)
 
 checker = renormalizing.RENormalizing([
     # Accommodate to exception wrapping in newer versions of mechanize
     (re.compile(r'httperror_seek_wrapper:', re.M), 'HTTPError:'),
     ])
 
+
 def suiteFromPackage(name):
     files = resource_listdir(__name__, name)
     suite = unittest.TestSuite()
@@ -35,11 +26,11 @@ def suiteFromPackage(name):
 
         dottedname = 'grokcore.formlib.ftests.%s.%s' % (name, filename[:-3])
         test = doctest.DocTestSuite(
-            dottedname, setUp=setUp, tearDown=tearDown,
+            dottedname,
             checker=checker,
-            extraglobs=dict(getRootFolder=getRootFolder),
-            optionflags=(doctest.ELLIPSIS+
-                         doctest.NORMALIZE_WHITESPACE+
+            extraglobs=dict(getRootFolder=FunctionalLayer.getRootFolder),
+            optionflags=(doctest.ELLIPSIS +
+                         doctest.NORMALIZE_WHITESPACE +
                          doctest.REPORT_NDIFF)
             )
         test.layer = FunctionalLayer
@@ -47,6 +38,7 @@ def suiteFromPackage(name):
         suite.addTest(test)
     return suite
 
+
 def test_suite():
     suite = unittest.TestSuite()
     for name in ['form']:
