@@ -1,12 +1,16 @@
+import doctest
 import re
 import unittest
 from pkg_resources import resource_listdir
-from zope.testing import doctest, cleanup, renormalizing
+
+from zope.testing import cleanup, renormalizing
 import zope.component.eventtesting
 
+
 def setUpZope(test):
     zope.component.eventtesting.setUp(test)
 
+
 def cleanUpZope(test):
     cleanup.cleanUp()
 
@@ -14,9 +18,10 @@ checker = renormalizing.RENormalizing([
     # str(Exception) has changed from Python 2.4 to 2.5 (due to
     # Exception now being a new-style class).  This changes the way
     # exceptions appear in traceback printouts.
-    (re.compile(r"ConfigurationExecutionError: <class '([\w.]+)'>:"),
-                r'ConfigurationExecutionError: \1:'),
-    ])
+    (re.compile(
+        r"ConfigurationExecutionError: <class '([\w.]+)'>:"),
+        r'ConfigurationExecutionError: \1:')])
+
 
 def suiteFromPackage(name):
     files = resource_listdir(__name__, name)
@@ -30,16 +35,17 @@ def suiteFromPackage(name):
             continue
 
         dottedname = 'grokcore.formlib.tests.%s.%s' % (name, filename[:-3])
-        test = doctest.DocTestSuite(dottedname,
-                                    setUp=setUpZope,
-                                    tearDown=cleanUpZope,
-                                    checker=checker,
-                                    optionflags=doctest.ELLIPSIS+
-                                    doctest.NORMALIZE_WHITESPACE)
+        test = doctest.DocTestSuite(
+            dottedname,
+            setUp=setUpZope,
+            tearDown=cleanUpZope,
+            checker=checker,
+            optionflags=doctest.ELLIPSIS + doctest.NORMALIZE_WHITESPACE)
 
         suite.addTest(test)
     return suite
 
+
 def test_suite():
     suite = unittest.TestSuite()
     for name in ['form']:
